<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 * 
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
    register_activation_hook( __FILE__, 'rwmb_check_php_version' );

    /**
     * Display notice for old PHP version.
     */
    function rwmb_check_php_version() {
        if ( version_compare( phpversion(), '5.3', '<' ) ) {
            die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
        }
    }




    require_once dirname( __FILE__ ) . '/inc/loader.php';
    $rwmb_loader = new RWMB_Loader();
    $rwmb_loader->init();


    add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

    $prefix = '_cmb_';


    //Add other metaboxs as needed

    


  // Open Code


    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('post'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Image:',
                'desc' => 'Show in blog page',
                'default' => '',
                'id' => $prefix . 'image123',
                'type' => 'file'
            ),
            array(
                'name' => 'Link share facebook:',
                'desc' => 'Input Link share facebook',
                'id'   => $prefix . 'single_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link share twitter:',
                'desc' => 'Input Link share twitter',
                'id'   => $prefix . 'single_twitter',
                'type'    => 'text',
            ),
        
            array(
                'name' => 'Link share instagram:',
                'desc' => 'Input Link share instagram',
                'id'   => $prefix . 'single_instagram',
                'type'    => 'text',
            ),

            array(
                'name' => 'Link share linkedin:',
                'desc' => 'Input Link share linkedin',
                'id'   => $prefix . 'single_linkedin',
                'type'    => 'text',
            ),

        )
    );

$meta_boxes[] = array(
        'id'         => 'testimonial_setting',
        'title'      => 'Testimonial Setting',
        'pages'      => array('testimonial'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Location:',
                'desc' => '',
                'default' => '',
                'id' => $prefix . 'location',
                'type' => 'text'
            ), 
        )
    );


$meta_boxes[] = array(
        'id'         => 'project_setting',
        'title'      => 'Project Setting',
        'pages'      => array('project'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Subtitle:',
                'desc' => '',
                'default' => '',
                'id' => $prefix . 'subtile',
                'type' => 'text'
            ), 
        )
    );

$meta_boxes[] = array(
        'id'         => 'product_setting',
        'title'      => 'Product Setting',
        'pages'      => array('product'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Link Facebook:',
                'desc' => 'Input link Facebook',
                'id'   => $prefix . 'link_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Twitter:',
                'desc' => 'Input link Twitter',
                'id'   => $prefix . 'link_twitter',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Instagram:',
                'desc' => 'Input link Instagram',
                'id'   => $prefix . 'link_instagram',
                'type'    => 'text',
            ),   
            array(
                'name' => 'Link Linkedin:',
                'desc' => 'Input link Linkedin',
                'id'   => $prefix . 'link_linkedin',
                'type'    => 'text',
            ),  
        )
    );


$meta_boxes[] = array(
        'id'         => 'team_setting',
        'title'      => 'team Setting',
        'pages'      => array('team'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Job',
                'desc' => 'Job',
                'default' => '',
                'id' => $prefix . 'team_job',
                'type' => 'text'
            ), 
            array(
                'name' => 'Link twitter:',
                'desc' => 'Input link Twitter',
                'id'   => $prefix . 'team_twitter',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Facebook:',
                'desc' => 'Input link Facebook',
                'id'   => $prefix . 'team_facebook',
                'type'    => 'text',
            ),
            array(
                'name' => 'Link Instagram:',
                'desc' => 'Input link Instagram',
                'id'   => $prefix . 'team_instagram',
                'type'    => 'text',
            ),   
            array(
                'name' => 'Link Linkedin:',
                'desc' => 'Input link Linkedin',
                'id'   => $prefix . 'team_linkedin',
                'type'    => 'text',
            ), 
        )
    );
    

// End Code
    return $meta_boxes;
});
}
