<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsDownloadApp extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-downloadapp';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 1 - Download App', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-file-download';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'downloadapp', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_downloadapp',
			[
				'label' => esc_html__( 'Download App', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'image_right_banner',
			[
				'label'       => esc_html__( 'Image Right Banner', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Right Banner', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_app_1',
			[
				'label'       => esc_html__( 'Image App 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image App 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_app_2',
			[
				'label'       => esc_html__( 'Image App 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image App 2', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Subtitle', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'Subtitle', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'link_down_1',
			[
				'label'       => __( 'Link Download 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'image_down_1',
			[
				'label'       => esc_html__( 'Image Download 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Download 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'link_down_2',
			[
				'label'       => __( 'Link Download 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'image_down_2',
			[
				'label'       => esc_html__( 'Image Download 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Download 2', 'bdevs-elementor' ),
			]	
		);	
		

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subtitle',
			[
				'label'   => esc_html__( 'Show Subtitle 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		
		

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<!-- App Download Area -->  
<section class="app_download">
    <div class="container">
        <div class="row single_features">
            <div class="col-12 col-md-6 col-lg-6">
                <div class="feature_banner wow fadeInLeft" data-wow-duration="2s" data-wow-delay=".3s">
                    <img src="<?php echo wp_kses_post($settings['image_right_banner']['url']); ?>" alt="" class="right_banner">
                    <div class="banner_shapes">
                        <img src="<?php echo wp_kses_post($settings['image_app_1']['url']); ?>" alt="" class="app_1">
                        <img src="<?php echo wp_kses_post($settings['image_app_2']['url']); ?>" alt="" class="app_3">
                    </div>
                </div>
            </div>
            <div class="col-12 col-md-6 col-lg-6">
                <div class="feature_intro_wrapper">    
                    <div class="feature_intro">

                    	<?php if (( '' !== $settings['title'] ) && ( $settings['show_title'] )) : ?>
                        <h2 class=" wow fadeInRight" data-wow-duration="2s" data-wow-delay=".2s"><?php echo wp_kses_post($settings['title']); ?></h2>
                    	<?php endif; ?>

                    	<?php if (( '' !== $settings['subtitle'] ) && ( $settings['show_subtitle'] )) : ?>
                        <p class=" wow fadeInRight" data-wow-duration="2s" data-wow-delay=".3s"><?php echo wp_kses_post($settings['subtitle']); ?></p>
                    	<?php endif; ?>

                    </div>
                    <div class="download_app_icon d-flex  wow fadeInUp" data-wow-duration="2s" data-wow-delay=".3s">
                        <a href="<?php echo wp_kses_post($settings['link_down_1']); ?>" class=""><img src="<?php echo wp_kses_post($settings['image_down_1']['url']); ?>" alt=""></a>                 
                        <a href="<?php echo wp_kses_post($settings['link_down_2']); ?>" class=""><img src="<?php echo wp_kses_post($settings['image_down_2']['url']); ?>" alt=""></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>

<?php
}

}
