<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsIntroHome1 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-introhome1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 1 - Intro Home 1', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-sidebar';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'introhome1', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_introhome1',
			[
				'label' => esc_html__( 'Intro Home 1', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'banner1',
			[
				'label'       => esc_html__( 'Image Banner 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'banner2',
			[
				'label'       => esc_html__( 'Image Banner 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner 2', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'banner3',
			[
				'label'       => esc_html__( 'Image Banner 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner 3', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title ', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle1',
			[
				'label'       => __( 'Subtitle 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'Subtitle 1', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle2',
			[
				'label'       => __( 'Subtitle 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'Subtitle 2', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'link_button1',
			[
				'label'       => __( 'Link Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'text_button1',
			[
				'label'       => __( 'Text Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Read more', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'link_button2',
			[
				'label'       => __( 'Link Button 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'text_button2',
			[
				'label'       => __( 'Text Button 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Contact us', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'image1',
			[
				'label'       => esc_html__( 'Image 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image2',
			[
				'label'       => esc_html__( 'Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 2', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image3',
			[
				'label'       => esc_html__( 'Image 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 3', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image4',
			[
				'label'       => esc_html__( 'Image 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 4', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image5',
			[
				'label'       => esc_html__( 'Image 5', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 5', 'bdevs-elementor' ),
			]	
		);	

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_title1',
			[
				'label'   => esc_html__( 'Show Title 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subtitle1',
			[
				'label'   => esc_html__( 'Show Subtitle 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		
		$this->add_control(
			'show_title2',
			[
				'label'   => esc_html__( 'Show Title 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subtitle2',
			[
				'label'   => esc_html__( 'Show Subtitle 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  
<!-- App Features -->  
<div id="intro_default" class="app_intro">
	<div class="intro_wrapper">
        <div class="container">  
            <div class="row">        
                <div class="col-sm-12 col-md-12 col-lg-6">
                    <div class="intro_banner">
                       <div class="screenshot">
                           <img src="<?php echo wp_kses_post($settings['banner1']['url']); ?>" alt="" class="screen_1  wow fadeInUp animated" data-wow-duration="2s" data-wow-delay=".2s">                           
                           <img src="<?php echo wp_kses_post($settings['banner2']['url']); ?>" alt="" class="screen_2  wow fadeInUp animated" data-wow-duration="2s" data-wow-delay=".5s">                           
                           <img src="<?php echo wp_kses_post($settings['banner3']['url']); ?>" alt="" class="screen_3  wow fadeInUp animated" data-wow-duration="2s" data-wow-delay=".8s">                           
                       </div>
                    </div>
                </div>
                 <div class="col-sm-12 col-md-12 col-lg-6">
                    <div class="intro_text">
                        <h4><?php echo wp_kses_post($settings['title']); ?></h4>
                        <h1 class="wow fadeInUp" data-wow-duration="2s" data-wow-delay=".2s"><?php echo wp_kses_post($settings['subtitle1']); ?></h1>
                        <p class="wow fadeInUp" data-wow-duration="2s" data-wow-delay=".3s"><?php echo wp_kses_post($settings['subtitle2']); ?></p>
                        <div class="intro_button d-flex wow fadeInUp" data-wow-duration="2s" data-wow-delay=".3s">
                            <a href="<?php echo wp_kses_post($settings['link_button1']); ?>" class="nav-link btn_gradient "><?php echo wp_kses_post($settings['text_button1']); ?></a>
                            <a href="<?php echo wp_kses_post($settings['link_button2']); ?>" class="nav-link d_btn_gradient btn_gradient app_contact_btn"><?php echo wp_kses_post($settings['text_button2']); ?></a>
                        </div>
                    </div>
                </div>
            </div>
        </div> 
    </div>  
    <div class="banner_shapes">
        <img src="<?php echo wp_kses_post($settings['image1']['url']); ?>" alt="" class="app_1">
        <img src="<?php echo wp_kses_post($settings['image2']['url']); ?>" alt="" class="app_2">        
        <img src="<?php echo wp_kses_post($settings['image3']['url']); ?>" alt="" class="app_3">
        <img src="<?php echo wp_kses_post($settings['image4']['url']); ?>" alt="" class="app_4">        
        <img src="<?php echo wp_kses_post($settings['image5']['url']); ?>" alt="" class="pen  wow fadeInLeftBig animated" data-wow-duration="2s" data-wow-delay=".2s">
    </div>
</div>
<!-- End Features section -->
<?php
}

}
