<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTestimonial1 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-testimonial1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 2 - Testimonial 1', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-user-circle-o';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'testimonial1', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_testimonial1',
			[
				'label' => esc_html__( 'Testimonial 1', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title ', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'image1',
			[
				'label'       => esc_html__( 'Image Banner Shape 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner Shape 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image2',
			[
				'label'       => esc_html__( 'Image Banner Shape 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner Shape 2', 'bdevs-elementor' ),
			]	
		);	

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title ', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			
			

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<!-- Start Testimonial section -->
<section class="product_testimonial">
    <div class="container">
        <div class="row">
            <div class="col-12 col-sm-12 col-md-12 col-lg-12">
                <div class="sub_title">

                	<?php if (( '' !== $settings['title'] ) && ( $settings['show_title'] )) : ?>
                    <h2 class=" wow fadeInUp" data-wow-duration="2s" data-wow-delay=".2s"><?php echo wp_kses_post($settings['title']); ?></h2>
                	<?php endif; ?>
                	
                </div>
            </div>
        </div>

         <div class="row"> 
            <div class="col-12 col-sm-12 col-md-12 col-lg-5">
                <div class="testimonial_pro_wrapper">
                    <div class="carousel_images product_pro_img">

                    	<?php
						    $wp_query = new \WP_Query(array('post_type' => 'testimonial'));
						    $args = array('post_type' => 'testimonial');
						?> 

						 <?php  
			                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'testimonial', 'paged' => $paged,  'orderby' => 'ID', 'order' => 'ASC'));
			            $args = new \WP_Query(array(
			                    'post_type'     => 'testimonial',
			                    'paged' => $paged,
			                ));
			                $i = 1;
			                while($wp_query->have_posts()): $wp_query->the_post(); 			      

			            ?>
                        <div class="restimonial_single_img">
                            <img src="<?php the_post_thumbnail_url(); ?>" alt="2" class="img-fluid">
                        </div>        
                        <?php endwhile; ?>            
                 
                    </div>
                    <div class="banner_shapes">
                        <img src="<?php print esc_url($settings['image1']['url']); ?>" alt="" class="app_1">
                        <img src="<?php print esc_url($settings['image2']['url']); ?>" alt="" class="app_2">
                        <img src="<?php print esc_url($settings['image3']['url']); ?>" alt="" class="app_3">        
                    </div>
                </div>
            </div>   

            <div class="col-12 col-sm-12 col-md-12 col-lg-7">
                <div class="testimonial_text_wrapper product_pro_content">

                	<?php
					    $wp_query = new \WP_Query(array('post_type' => 'testimonial'));
					    $args = array('post_type' => 'testimonial');
					?>

					 <?php  
		                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'testimonial', 'paged' => $paged,  'orderby' => 'ID', 'order' => 'ASC'));
		            $args = new \WP_Query(array(
		                    'post_type'     => 'testimonial',
		                    'paged' => $paged,
		                ));
		                $i = 1;
		                while($wp_query->have_posts()): $wp_query->the_post(); 
		                 $location_team = get_post_meta(get_the_ID(),'_cmb_location',true);

		            ?>
                    <div>
                        <div class="single_box wow fadeInUp" data-wow-duration="2s" data-wow-delay=".2s">
                            <p><?php the_content(); ?></p>
                            <h4><?php the_title(); ?> -<span> <?php echo wp_specialchars_decode($location_team);?></span></h4>
                        </div>
                    </div>
                	<?php endwhile; ?>
                </div>
            </div>
        </div>
    </div>
</section>
<!-- End Testimonial -->
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
            $('.product_pro_content').slick({

        slidesToShow: 1,

        slidesToScroll: 1,

        arrows: false,

        dots: true,

        fade: false,

        asNavFor: '.product_pro_img'

    });

    $('.product_pro_img').slick({

        slidesToShow: 1,

        slidesToScroll: 1,

        asNavFor: '.product_pro_content',

        dots: false,

        arrows: false,

        infinite: false,

        speed: 500,

        fade: true

    });
        
        
    </script>   
    <?php } ?>
<?php
}

}
