<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAgencyBlog extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-agencyblog';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 3 - Agency Blog', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-apps';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'agencyblog', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_agencyblog',
			[
				'label' => esc_html__( 'Agency Blog', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'text_button',
			[
				'label'       => __( 'Text Link Post Detail', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your text Link Button', 'bdevs-elementor' ),
				'default'     => __( 'Read more', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<!-- Agency Blogs -->
<section class="blog" id="blog_agency">
    <div class="container">  
        <div class="row">     

			 <?php  
			 $post_number =3;
                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'post', 'paged' => $paged,  'orderby' => 'ID', 'order' => 'ASC'));
            $args = new \WP_Query(array(
                    'post_type'     => 'post',
                    'paged' => $paged,
                ));
                $i = 1;
                while($wp_query->have_posts()): $wp_query->the_post(); 
                $blog_image = get_post_meta(get_the_ID(),'_cmb_image123',true);
            ?>
            <div class="col-12 col-md-6 col-lg-4">
                <div class="signle_services single_services_2 wow fadeInUp" data-wow-duration="2s" data-wow-delay=".3s">
                    <div class="blog_banner">
                        <a href="<?php the_permalink();?>" title=""><img src="<?php echo wp_get_attachment_url($blog_image);?>" alt=""></a>
                    </div>
                    <h3><a href="<?php the_permalink();?>" title=""><?php the_title(); ?></a></h3>
                    <p>
                    	<?php if(isset($sassnex_redux_demo['blog_excerpt'])){?>
                        <?php echo esc_attr(sassnex_excerpt($sassnex_redux_demo['blog_excerpt'])); ?>
                        <?php }else{?>
                        <?php echo esc_attr(sassnex_excerpt(20)); 
                        ?>
                    	<?php } ?>
                    </p>
                    <a href="<?php the_permalink();?>" title=""><?php echo wp_kses_post($settings['text_button']); ?></a>
                </div>
            </div>                    
   			<?php endwhile; ?>
        </div>
    </div>
</section><!-- End Blogs -->
<?php
}

}
