<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsCountLead extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-countlead';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 3 - Count Lead', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-countdown';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'countlead', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_countlead',
			[
				'label' => esc_html__( 'Count Lead', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'SubTitle', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'SubTitle', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'number1',
			[
				'label'       => __( 'Number 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your number 1', 'bdevs-elementor' ),
				'default'     => __( '0', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subnumber1',
			[
				'label'       => __( 'SubNumber 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your subnumber 1', 'bdevs-elementor' ),
				'default'     => __( 'SubNumber', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'number2',
			[
				'label'       => __( 'Number 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your number 2', 'bdevs-elementor' ),
				'default'     => __( '0', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subnumber2',
			[
				'label'       => __( 'SubNumber 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your subnumber 2', 'bdevs-elementor' ),
				'default'     => __( 'SubNumber', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'number3',
			[
				'label'       => __( 'Number 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your number 3', 'bdevs-elementor' ),
				'default'     => __( '0', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subnumber3',
			[
				'label'       => __( 'SubNumber 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your subnumber 3', 'bdevs-elementor' ),
				'default'     => __( 'SubNumber', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'number4',
			[
				'label'       => __( 'Number 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your number 4', 'bdevs-elementor' ),
				'default'     => __( '0', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subnumber4',
			[
				'label'       => __( 'SubNumber 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your subnumber 4', 'bdevs-elementor' ),
				'default'     => __( 'SubNumber', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'image',
			[
				'label'       => esc_html__( 'Image', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape1',
			[
				'label'       => esc_html__( 'Image Shape 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape2',
			[
				'label'       => esc_html__( 'Image Shape 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 2', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape3',
			[
				'label'       => esc_html__( 'Image Shape 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 3', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape4',
			[
				'label'       => esc_html__( 'Image Shape 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 4', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape5',
			[
				'label'       => esc_html__( 'Image Shape 5', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 5', 'bdevs-elementor' ),
			]	
		);	
		

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	
		

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<!-- Count lead Agency -->
<section class="count_lead_agency">
    <div class="container">
        <div class="row">        
            <div class="col-sm-12 col-md-12 col-lg-12">
                <div class="sub_title">
                    <h2><?php echo wp_kses_post($settings['title']); ?></h2>
                    <p><?php echo wp_kses_post($settings['subtitle']); ?></p>
                </div>
            </div>
        </div>
        <div class="row d-flex justify-content-between count_load_wrapper">
            <div class="col-md-6">      
                <div class="row">
                    <div class="col-12 col-md-6 col-lg-6 p-0">
                        <div class="count_lead_single count_lead_single_1 count_lead_single_2">
                            <h3><?php echo wp_kses_post($settings['number1']); ?></h3>
                            <span><?php echo wp_kses_post($settings['subnumber1']); ?></span>
                        </div>
                    </div>            

                    <div class="col-12 col-md-6 col-lg-6 p-0">
                        <div class="count_lead_single count_lead_single_1">
                            <h3><?php echo wp_kses_post($settings['number2']); ?></h3>
                            <span><?php echo wp_kses_post($settings['subnumber2']); ?></span>
                        </div>
                    </div>            

                    <div class="col-12 col-md-6 col-lg-6 p-0">
                        <div class="count_lead_single count_lead_single_2">
                            <h3><?php echo wp_kses_post($settings['number3']); ?></h3>
                            <span><?php echo wp_kses_post($settings['subnumber3']); ?></span>
                        </div>
                    </div>            

                    <div class="col-12 col-md-6 col-lg-6 p-0">
                        <div class="count_lead_single">
                            <h3><?php echo wp_kses_post($settings['number4']); ?></h3>
                            <span><?php echo wp_kses_post($settings['subnumber4']); ?></span>
                        </div>
                    </div>
                </div>    
            </div>
            <div class="col-md-5">      
                <div class="count_lead_banner wow fadeInRight" data-wow-duration="2s" data-wow-delay=".2s">
                   <img src="<?php print esc_url($settings['image']['url']); ?>" alt="">
                </div>
            </div>
            <div class="banner_shapes">
                <img src="<?php print esc_url($settings['image_shape1']['url']); ?>" alt="" class="agency_1 wow fadeInDown" data-wow-duration="2s" data-wow-delay=".2s">
                <img src="<?php print esc_url($settings['image_shape2']['url']); ?>" alt="" class="agency_2 wow fadeInDown" data-wow-duration="2s" data-wow-delay=".3s">        
                <img src="<?php print esc_url($settings['image_shape3']['url']); ?>" alt="" class="agency_3 wow fadeInDown" data-wow-duration="2s" data-wow-delay=".4s">
                <img src="<?php print esc_url($settings['image_shape4']['url']); ?>" alt="" class="agency_4 wow fadeInDown" data-wow-duration="2s" data-wow-delay=".5s">                          
                <img src="<?php print esc_url($settings['image_shape5']['url']); ?>" alt="" class="agency_5 wow fadeInDown" data-wow-duration="2s" data-wow-delay=".6s">
            </div>
        </div> 
    </div>
</section>
<!--End Count lead Agency -->

<?php
}

}
