<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsVideoAgency extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-videoagency';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 3 - Video Agency', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-video-playlist';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'videoagency', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_videoagency',
			[
				'label' => esc_html__( 'Video Agency', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'image_video',
			[
				'label'       => esc_html__( 'Image Video', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Video', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'video_link',
			[
				'label'       => __( 'Link Video', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link video', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'image_shape1',
			[
				'label'       => esc_html__( 'Image Shape 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape2',
			[
				'label'       => esc_html__( 'Image Shape 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 2', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape3',
			[
				'label'       => esc_html__( 'Image Shape 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 3', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape4',
			[
				'label'       => esc_html__( 'Image Shape 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 4', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape5',
			[
				'label'       => esc_html__( 'Image Shape 5', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 5', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape6',
			[
				'label'       => esc_html__( 'Image Shape 6', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 6', 'bdevs-elementor' ),
			]	
		);	
		

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);	

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<!-- Our Video Agency -->
<section class="video_intro_agency">
    <div class="container-fluid">
        <div class="row ">
            <div class="col-12 col-md-12 col-lg-12 p-0">
                <div class="agency_video_wrapper">
                    <div class="video_banner">
                        <img src="<?php print esc_url($settings['image_video']['url']); ?>" alt="" class="img-fluid banner_img">
                        <div class="banner_shapes">
                            <img src="<?php print esc_url($settings['image_shape1']['url']); ?>" alt="" class="agency_1 wow fadeInRight" data-wow-duration="2s" data-wow-delay=".2s">
                            <img src="<?php print esc_url($settings['image_shape2']['url']); ?>" alt="" class="agency_2 wow fadeInRight" data-wow-duration="2s" data-wow-delay=".3s">        
                            <img src="<?php print esc_url($settings['image_shape3']['url']); ?>" alt="" class="agency_3 wow fadeInRight" data-wow-duration="2s" data-wow-delay=".4s">
                            <img src="<?php print esc_url($settings['image_shape4']['url']); ?>" alt="" class="agency_4 wow fadeInRight" data-wow-duration="2s" data-wow-delay=".5s">                           
                            <img src="<?php print esc_url($settings['image_shape5']['url']); ?>" alt="" class="agency_6 wow fadeInRight" data-wow-duration="2s" data-wow-delay=".6s">
                            <img src="<?php print esc_url($settings['image_shape6']['url']); ?>" alt="" class="agency_5 wow fadeInRight" data-wow-duration="2s" data-wow-delay=".7s">        
                        </div>
                        <div class="video_wrapper">
                            <div class="video-play-btn">
                                <a href="<?php echo wp_kses_post($settings['video_link']); ?>" class="video-iframe"><i class="flaticon-play-button services_icon"></i></a>
                            </div>
                        </div> 
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
<!-- End Video section -->

<?php
}

}
