<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsIntroHome5 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-introhome5';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 5 - Intro Home 5', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-sidebar';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'introhome5', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_introhome5',
			[
				'label' => esc_html__( 'Intro Home 5', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title ', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Subtitle ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'Subtitle ', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'link_button1',
			[
				'label'       => __( 'Link Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'text_button1',
			[
				'label'       => __( 'Text Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Sign Up', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'link_button2',
			[
				'label'       => __( 'Link Button 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'text_button2',
			[
				'label'       => __( 'Text Button 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Find Out More', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'banner',
			[
				'label'       => esc_html__( 'Image Banner', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape1',
			[
				'label'       => esc_html__( 'Image Shape 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image_shape2',
			[
				'label'       => esc_html__( 'Image Shape 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Shape 2', 'bdevs-elementor' ),
			]	
		);	

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  


	
<div id="intro_detault" class="mheader">
	<div class="intro_wrapper">
        <div class="container">  
            <div class="row">        
                <div class="col-sm-12 col-md-12 col-lg-6">
                    <div class="intro_text intro_text_marketing">
                        <h1 class="wow fadeInUp" data-wow-duration="2s" data-wow-delay=".2s"><?php echo wp_kses_post($settings['title']); ?></h1>
                        <p class="wow fadeInUp" data-wow-duration="2s" data-wow-delay=".3s"><?php echo wp_kses_post($settings['subtitle']); ?></p>
                        <div class="intro_button intro_button_m d-flex wow fadeInUp" data-wow-duration="2s" data-wow-delay=".3s">
                            <a href="<?php echo wp_kses_post($settings['link_button1']); ?>" class="nav-link active"><?php echo wp_kses_post($settings['text_button1']); ?></a>
                            <a href="<?php echo wp_kses_post($settings['link_button2']); ?>" class="nav-link"><?php echo wp_kses_post($settings['text_button2']); ?></a>
                        </div>
                    </div>
                </div>
                <div class="col-sm-12 col-md-12 col-lg-6">
                    <div class="intro_banner intro_banner_marketing wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".2s">
                       <img src="<?php echo wp_kses_post($settings['banner']['url']); ?>" alt="" >
                    </div>
                </div>
            </div>
        </div> 
    </div>  
    <div class="banner_shapes">
    	<img src="<?php echo wp_kses_post($settings['image_shape1']['url']); ?>" alt="" class="m_banner_1">
        <img src="<?php echo wp_kses_post($settings['image_shape2']['url']); ?>" alt="" class="m_banner_2">
    </div>
</div> 
<?php
}

}
