<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsMarketingFeatures extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-marketingfeatures';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 5 - Marketing Features', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-featured-image';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'marketingfeatures', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_marketingfeatures',
			[
				'label' => esc_html__( 'Marketing Features', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'title_1',
			[
				'label'       => __( 'Title 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title 1', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle_11',
			[
				'label'       => __( 'SubTitle 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'SubTitle 1', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'subtitle_12',
			[
				'label'       => __( 'SubTitle 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'SubTitle 1', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'link_button_1',
			[
				'label'       => __( 'Link Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);		
		$this->add_control(
			'text_button_1',
			[
				'label'       => __( 'Text Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Get Started', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'banner_image_1',
			[
				'label'       => esc_html__( 'Image Banner 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'title_2',
			[
				'label'       => __( 'Title 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title 2', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle_21',
			[
				'label'       => __( 'SubTitle 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'SubTitle 2', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'subtitle_22',
			[
				'label'       => __( 'SubTitle 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'SubTitle 2', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_button_2',
			[
				'label'       => __( 'Link Button 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);		
		$this->add_control(
			'text_button_2',
			[
				'label'       => __( 'Text Button 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Get Started', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'banner_image_2',
			[
				'label'       => esc_html__( 'Image Banner 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner 2', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'title_3',
			[
				'label'       => __( 'Title 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title 3', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle_3',
			[
				'label'       => __( 'SubTitle 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'SubTitle 3', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'subtitle_3',
			[
				'label'       => __( 'SubTitle 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'SubTitle 3', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_button_3',
			[
				'label'       => __( 'Link Button 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'text_button_3',
			[
				'label'       => __( 'Text Button 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Get Started', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'banner_image_3',
			[
				'label'       => esc_html__( 'Image Banner 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image Banner 3', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'shape_image_1',
			[
				'label'       => esc_html__( 'Shape Image 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Shape Image 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'shape_image_2',
			[
				'label'       => esc_html__( 'Shape Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Shape Image 2', 'bdevs-elementor' ),
			]	
		);		

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	
		

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<!-- Marketing Features -->
<section class="features">
    <div class="container">
        
        <div class="row single_features">
            <div class="col-12 col-md-6 col-lg-7">
                <div class="feature_banner feature_banner_r_1  wow fadeInLeft animated" data-wow-duration="2s" data-wow-delay=".2s">
                    <img src="<?php print esc_url($settings['banner_image_1']['url']); ?>" alt="" class="right_banner">
                </div>
            </div>       
            <div class="col-12 col-md-6 col-lg-5">
                <div class="feature_intro feature_intro_1">
                    <h2 class="wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".2s"><?php echo wp_kses_post($settings['title_1']); ?></h2>
                    <p class=" wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".3s"><?php echo wp_kses_post($settings['subtitle_11']); ?></p>
                    <p class=" wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".3s"><?php echo wp_kses_post($settings['subtitle_12']); ?></p>
                    <a href="<?php echo wp_kses_post($settings['link_button_1']); ?>" class="default_btn  wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".4s"><?php echo wp_kses_post($settings['text_button_1']); ?></a>
                </div>

            </div>
        </div>

        <div class="row single_features">
            <div class="col-12 col-md-6 col-lg-5">
                <div class="feature_intro feature_intro_2">
                    <h2 class=" wow fadeInLeft animated" data-wow-duration="2s" data-wow-delay=".2s"><?php echo wp_kses_post($settings['title_2']); ?></h2>
                    <p class=" wow fadeInLeft animated" data-wow-duration="2s" data-wow-delay=".3s"><?php echo wp_kses_post($settings['subtitle_21']); ?></p>
                    <p class=" wow fadeInLeft animated" data-wow-duration="2s" data-wow-delay=".3s"><?php echo wp_kses_post($settings['subtitle_22']); ?></p>
                    <a href="<?php echo wp_kses_post($settings['link_button_2']); ?>" class="default_btn  wow fadeInLeft animated" data-wow-duration="2s" data-wow-delay=".4s"><?php echo wp_kses_post($settings['text_button_2']); ?></a>
                </div>

            </div>
            <div class="col-12 col-md-6 col-lg-7">
                <div class="feature_banner feature_banner_r_2  wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".2s">
                    <img src="<?php print esc_url($settings['banner_image_2']['url']); ?>" alt="">
                </div>
            </div>
        </div>

        <div class="row single_features">
            <div class="col-12 col-md-6 col-lg-7">
                <div class="feature_banner feature_banner_r_3  wow fadeInLeft animated" data-wow-duration="2s" data-wow-delay=".2s">
                    <img src="<?php print esc_url($settings['banner_image_3']['url']); ?>" alt="" class="right_banner">
                    <div class="banner_shapes">
                        <img src="<?php print esc_url($settings['shape_image_1']['url']); ?>" alt="" class="shape_1">
                        <img src="<?php print esc_url($settings['shape_image_2']['url']); ?>" alt="" class="shape_2">              
                    </div>
                </div>
            </div>
            <div class="col-12 col-md-6 col-lg-5">
                <div class="feature_intro feature_intro_3">
                    <h2 class=" wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".2s"><?php echo wp_kses_post($settings['title_3']); ?></h2>
                    <p class=" wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".3s"><?php echo wp_kses_post($settings['subtitle_3']); ?></p>
                    <a href="<?php echo wp_kses_post($settings['link_button_3']); ?>" class="default_btn  wow fadeInRight animated" data-wow-duration="2s" data-wow-delay=".4s"><?php echo wp_kses_post($settings['text_button_3']); ?></a>
                </div>
            </div>
        </div>
    </div>
</section>
<!-- End Features section -->

<?php
}

}
