<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTeamMarketing extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-teammarketing';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 5 - Team Marketing', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-user-circle-o';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'teammarketing', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_teammarketing',
			[
				'label' => esc_html__( 'Team Marketing', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title ', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Subtitle ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'Subtitle ', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'link_button',
			[
				'label'       => __( 'Link Button ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( '# ', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'text_button',
			[
				'label'       => __( 'Text Button ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'Meet All Person ', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'number_posts_page',
			[
				'label'       => __( 'Number Posts Page ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( '4', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'image1',
			[
				'label'       => esc_html__( 'Image 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image2',
			[
				'label'       => esc_html__( 'Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 2', 'bdevs-elementor' ),
			]	
		);		

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title ', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subtitle',
			[
				'label'   => esc_html__( 'Show Subtitle ', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		$post_number = wp_kses_post($settings['number_posts_page']);
		?>  

<!-- Team section heare -->
<section class="team">
    <div class="container">  
        <div class="row">        
            <div class="col-sm-12 col-md-12 col-lg-12">
                <div class="sub_title  wow fadeInUp animated" data-wow-duration="2s" data-wow-delay=".2s">
                    <?php if (( '' !== $settings['title'] ) && ( $settings['show_title'] )) : ?>
                    <h2><?php echo wp_kses_post($settings['title']); ?></h2>
                    <?php endif; ?>

                   	<?php if (( '' !== $settings['subtitle'] ) && ( $settings['show_subtitle'] )) : ?>
                    <p><?php echo wp_kses_post($settings['subtitle']); ?></p>
                	<?php endif; ?>
                </div>
            </div>
        </div>

        <div class="row"> 
            <div class="team_wrapper_items col-12 col-md-12 col-lg-12 p-0 d-flex justify-content-between">

				 <?php  
	                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'team', 'paged' => $paged,  'orderby' => 'ID', 'order' => 'ASC'));
	            $args = new \WP_Query(array(
	                    'post_type'     => 'team',
	                    'paged' => $paged,
	                ));
	                $i = 1;
	                while($wp_query->have_posts()): $wp_query->the_post(); 
	                $team_job = get_post_meta(get_the_ID(),'_cmb_team_job',true);
	                $link_fb = get_post_meta(get_the_ID(),'_cmb_team_facebook',true);
	                $link_fb = get_post_meta(get_the_ID(),'_cmb_team_twitter',true);
	                $link_fb = get_post_meta(get_the_ID(),'_cmb_team_instagram',true);
	                $link_fb = get_post_meta(get_the_ID(),'_cmb_team_linkedin',true);
	            ?>
                <div class="signel_team  wow fadeInUp animated" data-wow-duration="2s" data-wow-delay=".<?php echo esc_attr($i+1); ?>s">
                    <div class="team_pro">
                        <?php the_post_thumbnail(); ?>
                    </div>
                    <h3><a href="<?php the_permalink();?>" title=""><?php the_title(); ?></a></h3>
                    <span class="sub_title"><?php echo wp_specialchars_decode($team_job);?></span>
                    <ul class="social_iocns d-flex justify-content-center">
                        <li><a href="<?php echo wp_specialchars_decode($link_fb);?>"><i class="flaticon-facebook-logo icon_tw"></i></a></li>
                        <li><a href="<?php echo wp_specialchars_decode($link_tw);?>"><i class="flaticon-twitter icon_fb"></i></a></li>
                        <li><a href="<?php echo wp_specialchars_decode($link_in);?>"><i class="flaticon-instagram-logo icon_pin"></i></a></li>
                        <li><a href="<?php echo wp_specialchars_decode($link_li);?>"><i class="flaticon-linkedin-logo icon_link"></i></a></li>
                    </ul>
                </div>
           		<?php endwhile; ?>
            </div>
           <div class="col-12 col-md-12 col-lg-12 p-0">
                <div class="meet_all_parson">
                    <a href="<?php echo wp_kses_post($settings['link_button']); ?>" title=""><?php echo wp_kses_post($settings['text_button']); ?><img src="<?php print esc_url($settings['image1']['url']); ?>" alt="" class="btn_icon btn_icon_1"> <img src="<?php print esc_url($settings['image2']['url']); ?>" alt="" class="btn_icon btn_icon_2"></a>
                </div>
            </div>    
        </div>
    </div>
</section>

<?php
}

}
