<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsIntroTeam extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-introteam';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Intro Team', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-sidebar';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'introteam', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_introteam',
			[
				'label' => esc_html__( 'Intro Team', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'image1',
			[
				'label'       => esc_html__( 'Image 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image2',
			[
				'label'       => esc_html__( 'Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 2', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image3',
			[
				'label'       => esc_html__( 'Image 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 3', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image4',
			[
				'label'       => esc_html__( 'Image 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 4', 'bdevs-elementor' ),
			]	
		);	

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  



	<div class="sassnex-bc">
		<div class="intro_wrapper">
	        <div class="container">  
	            <div class="row">        
	                <div class="col-sm-12 col-md-12 col-lg-12">
	                    <div class="intro_text">
	                        <h1 class="wow fadeInUp" data-wow-duration="2s" data-wow-delay=".2s">
	                        	
			            	<?php if(get_the_title() !== null){?>
			                <?php the_title();?>
			                <?php }else{
			                    echo esc_html__( 'Team Page', 'sassnex' );
			                }?>
	                        </h1>
	                        <div class="select_pages">
	                            <a href="<?php echo esc_url(home_url('/ ')); ?>" title="">
	                            	<?php if(isset($sassnex_redux_demo['home'])){?>
					                  <?php echo htmlspecialchars_decode(esc_attr($sassnex_redux_demo['home']));?>
					                  <?php }else{?>
					                  <?php echo esc_html__( 'Home', 'sassnex' );
					                  }?>
	                            </a> <span>
	                            	<?php if(get_the_title() !== null){?>
				                    <?php the_title();?>
				                    <?php }else{
				                        echo esc_html__( 'Team Page', 'sassnex' );
				                    }?>
	                            </span> 
	                        </div>
	                    </div>
	                </div>
	            </div>
	        </div> 
	    </div>  
	    <div class="banner_shapes">
	        <img src="<?php echo wp_kses_post($settings['image1']['url']); ?>" alt="" class="agency_1 img-fluid">
	        <img src="<?php echo wp_kses_post($settings['image2']['url']); ?>" alt="" class="agency_2">
	        <img src="<?php echo wp_kses_post($settings['image3']['url']); ?>" alt="" class="agency_6">        
	        <img src="<?php echo wp_kses_post($settings['image4']['url']); ?>" alt="" class="agency_3">      
	    </div>
	</div>
<?php
}

}
