<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsPricingPackages extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-pricingpackages';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Page + Team - Pricing Page - Pricing Packages', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-price-table';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'pricingpackages', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_pricingpackages',
			[
				'label' => esc_html__( 'Pricing Packages', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'SubTitle', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'SubTitle', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);		
		$this->add_control(
			'text_button_1',
			[
				'label'       => __( 'Text Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your text button 1', 'bdevs-elementor' ),
				'default'     => __( 'Monthly', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'text_button_2',
			[
				'label'       => __( 'Text Button 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your text button 2', 'bdevs-elementor' ),
				'default'     => __( 'Yearly', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'tabs1',
			[
				'label' => esc_html__( 'Service App Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [		
					[
						'name'    => 'icon_item',
						'label'   => esc_html__( 'Avata Image Item', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
					[
						'name'        => 'title_item',
						'label'       => esc_html__( 'Title Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title Item' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'price_item',
						'label'       => esc_html__( 'Price Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::NUMBER,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '0' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'time_item',
						'label'       => esc_html__( 'Time Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Time Item' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'sub_item',
						'label'       => esc_html__( 'Sub Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::WYSIWYG,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Sub Item' , 'bdevs-elementor' ),
						'label_block' => true,
					],						
					[
						'name'        => 'link_item',
						'label'       => esc_html__( 'Link Button Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'text_button',
						'label'       => esc_html__( 'Text Button Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Learn More' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);	
		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Service App Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [		
					[
						'name'    => 'icon_item',
						'label'   => esc_html__( 'Avata Image Item', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
					[
						'name'        => 'title_item',
						'label'       => esc_html__( 'Title Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title Item' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'price_item',
						'label'       => esc_html__( 'Price Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::NUMBER,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '0' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'time_item',
						'label'       => esc_html__( 'Time Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Time Item' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'sub_item',
						'label'       => esc_html__( 'Sub Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::WYSIWYG,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Sub Item' , 'bdevs-elementor' ),
						'label_block' => true,
					],						
					[
						'name'        => 'link_item',
						'label'       => esc_html__( 'Link Button Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'text_button',
						'label'       => esc_html__( 'Text Button Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Learn More' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);	

		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	
	
		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title ', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subtitle',
			[
				'label'   => esc_html__( 'Show Subtitle ', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<!-- Pricing Packages --> 
<section class="pricing_packages">
    <div class="container">
        <div class="row">        
            <div class="col-sm-12 col-md-12 col-lg-12">
                <div class="sub_title">
                    <?php if (( '' !== $settings['title'] ) && ( $settings['show_title'] )) : ?>
                    <h2><?php echo wp_kses_post($settings['title']); ?></h2>
                	<?php endif; ?>

                	<?php if (( '' !== $settings['subtitle'] ) && ( $settings['show_subtitle'] )) : ?>
                    <p><?php echo wp_kses_post($settings['subtitle']); ?></p>
                	<?php endif; ?>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-sm-12 col-md-12 col-lg-12">
                <div role="tabpanel">
                    <div class="d-flex justify-content-between">
                        <div class="btn-items d-flex">
                            <ul class="nav nav-tabs " role="tablist">
                                <li class="nav-item">
                                    <a href="#tab1" class="nav-link active" aria-controls="tab1" role="tab" data-toggle="tab"><?php echo wp_kses_post($settings['text_button_1']); ?></a>
                                </li>
                                <li class="nav-item">
                                    <a href="#tab2" class="nav-link" aria-controls="tab2" role="tab" data-toggle="tab"><?php echo wp_kses_post($settings['text_button_2']); ?></a>
                                </li>
                                
                            </ul>
                        </div>
                    </div>

                    <!-- Tab panes -->
                    <div class="tab-content eco_templates_items">
                        <div role="tabpanel" class="tab-pane active in fade show" id="tab1">
                            <div class="pricing_payment">
                                <div class="row">
                                	<?php 
						            foreach ( $settings['tabs1'] as $item ) : 
									?>
                                    <div class="col-12 col-md-6 col-lg-4">
                                        <div class="payment_pricing_wrapper">
                                            <div class="pricing_icon">
                                                <img src="<?php echo esc_url($item['icon_item']['url']); ?>" alt="">
                                            </div>
                                            <div class="pricing_content">
                                                <h3><?php echo wp_kses_post($item['title_item']); ?></h3>
                                                <span><?php echo wp_kses_post($item['time_item']); ?></span>
                                                <h4>$<?php echo wp_kses_post($item['price_item']); ?></h4>
                                                <ul class="">
                                                   <?php echo wp_kses_post($item['sub_item']); ?>
                                                </ul>
                                            </div>
                                            <a href="<?php echo wp_kses_post($item['link_item']); ?>" title=""><?php echo wp_kses_post($item['text_button']); ?></a>
                                        </div>
                                    </div>   
                                	<?php endforeach; ?>
                                </div>
                            </div>
                        </div>

                        <div role="tabpanel" class="tab-pane fade" id="tab2">
                            <div class="pricing_payment">
                                <div class="row">
                                	<?php 
						            foreach ( $settings['tabs2'] as $item ) : 
									?>
                                    <div class="col-12 col-md-6 col-lg-4">
                                        <div class="payment_pricing_wrapper">
                                            <div class="pricing_icon">
                                                <img src="<?php echo esc_url($item['icon_item']['url']); ?>" alt="">
                                            </div>
                                            <div class="pricing_content">
                                                <h3><?php echo wp_kses_post($item['title_item']); ?></h3>
                                                <span><?php echo wp_kses_post($item['time_item']); ?></span>
                                                <h4>$<?php echo wp_kses_post($item['price_item']); ?></h4>
                                                <ul class="">
                                                   <?php echo wp_kses_post($item['sub_item']); ?>
                                                </ul>
                                            </div>
                                            <a href="<?php echo wp_kses_post($item['link_item']); ?>" title=""><?php echo wp_kses_post($item['text_button']); ?></a>
                                        </div>
                                    </div>            
                                	<?php endforeach; ?>
                                </div>
                            </div>
                        </div>                        
                    </div>
                </div>
            </div><!-- Ends: .feature-tabs -->
        </div>        
    </div>   
    <img src="images/shapes/blure_shape.png" alt="" class="shape_blure">
</section>
<?php
}

}
